==> estnltk-1.6.5.5b0-cp36-cp36m-manylinux2014_x86_64.whl: estnltk/taggers/__init__.py <==
from estnltk.taggers.tagger import Tagger
from estnltk.taggers.retagger import Retagger

from estnltk.taggers.tagger_tester import TaggerTester

from estnltk.taggers.standard_taggers.atomizer import Atomizer
from estnltk.taggers.standard_taggers.annotation_rewriter import AnnotationRewriter
from estnltk.taggers.standard_taggers.span_rewriter import SpanRewriter
from estnltk.taggers.standard_taggers.attribute_comparison_tagger import AttributeComparisonTagger

from estnltk.taggers.combined_tagger import CombinedTagger

from estnltk.taggers.dict_taggers.vocabulary import Vocabulary
from estnltk.taggers.dict_taggers.phrase_tagger import PhraseTagger
from estnltk.taggers.dict_taggers.regex_tagger import RegexTagger
from estnltk.taggers.dict_taggers.span_tagger import SpanTagger

from estnltk.taggers.grammar_taggers.grammar_parsing_tagger import GrammarParsingTagger

from estnltk.taggers.raw_text_tagging.date_tagger.date_tagger import DateTagger

from estnltk.taggers.morph_analysis.postanalysis_tagger import PostMorphAnalysisTagger
from estnltk.taggers.morph_analysis.morf import VabamorfTagger
from estnltk.taggers.morph_analysis.gt_morf import GTMorphConverter
from estnltk.taggers.morph_analysis.morf import VabamorfAnalyzer
from estnltk.taggers.morph_analysis.morf import VabamorfDisambiguator
from estnltk.taggers.morph_analysis.userdict_tagger import UserDictTagger
from estnltk.taggers.morph_analysis.vm_analysis_reorderer import MorphAnalysisReorderer

from estnltk.taggers.morph_analysis.vm_spellcheck import SpellCheckRetagger

from estnltk.taggers.morph_analysis.cb_disambiguator import CorpusBasedMorphDisambiguator
from estnltk.taggers.morph_analysis.vm_corpus_tagger import VabamorfCorpusTagger

from estnltk.taggers.sequential_tagger import SequentialTagger

from estnltk.taggers.standard_taggers.disambiguating_tagger import DisambiguatingTagger
from estnltk.taggers.standard_taggers.enveloping_gap_tagger import EnvelopingGapTagger
from estnltk.taggers.standard_taggers.flatten_tagger import FlattenTagger
from estnltk.taggers.standard_taggers.gap_tagger import GapTagger
from estnltk.taggers.standard_taggers.layer_merge_tagger import MergeTagger
from estnltk.taggers.standard_taggers.diff_tagger import DiffTagger
from estnltk.taggers.standard_taggers.text_segments_tagger import TextSegmentsTagger

from estnltk.taggers.standard_taggers.timex_tagger import TimexTagger

from estnltk.taggers.miscellaneous.robust_date_number_tagger import RobustDateNumberTagger
from estnltk.taggers.miscellaneous.address_tagger import AddressPartTagger
from estnltk.taggers.miscellaneous.address_tagger import AddressGrammarTagger
from estnltk.taggers.miscellaneous.adjective_phrase_tagger import AdjectivePhraseTagger
from estnltk.taggers.miscellaneous.flesch_tagger import SentenceFleschScoreRetagger
from estnltk.taggers.verb_chains import VerbChainDetector

from estnltk.taggers.text_segmentation.tokens_tagger import TokensTagger
from estnltk.taggers.text_segmentation.word_tagger import WordTagger
from estnltk.taggers.text_segmentation.sentence_tokenizer import SentenceTokenizer
from estnltk.taggers.text_segmentation.paragraph_tokenizer import ParagraphTokenizer
from estnltk.taggers.text_segmentation.compound_token_tagger import CompoundTokenTagger
from estnltk.taggers.text_segmentation.clause_segmenter import ClauseSegmenter

# Taggers for processing pretokenized texts:
from estnltk.taggers.text_segmentation.whitespace_tokens_tagger import WhiteSpaceTokensTagger
from estnltk.taggers.text_segmentation.pretokenized_text_compound_tokens_tagger import PretokenizedTextCompoundTokensTagger

from estnltk.taggers.syntax_preprocessing.pronoun_type_retagger import PronounTypeRetagger
from estnltk.taggers.syntax_preprocessing.verb_extension_suffix_tagger import VerbExtensionSuffixRetagger
from estnltk.taggers.syntax_preprocessing.subcat_tagger import SubcatRetagger
from estnltk.taggers.syntax_preprocessing.subcat_tagger import SubcatTagger
from estnltk.taggers.syntax_preprocessing.finite_form_tagger import FiniteFormTagger
from estnltk.taggers.syntax_preprocessing.morph_extended_tagger import MorphExtendedTagger

from estnltk.taggers.syntax.visl_tagger import VislTagger
from estnltk.taggers.syntax.conll_morph_tagger import ConllMorphTagger
from estnltk.taggers.syntax.syntax_dependency_retagger import SyntaxDependencyRetagger
from estnltk.taggers.syntax.syntax_diff_retagger import SyntaxDiffRetagger
from estnltk.taggers.syntax.syntax_las_tagger import SyntaxLasTagger

from estnltk.taggers.standard_taggers.attribute_comparison_tagger import AttributeComparisonTagger

==> estnltk-1.6.6b0-cp36-cp36m-manylinux2014_x86_64.whl: estnltk/taggers/__init__.py <==
from estnltk.taggers.tagger import Tagger
from estnltk.taggers.retagger import Retagger

from estnltk.taggers.tagger_tester import TaggerTester

from estnltk.taggers.standard_taggers.atomizer import Atomizer
from estnltk.taggers.standard_taggers.annotation_rewriter import AnnotationRewriter
from estnltk.taggers.standard_taggers.span_rewriter import SpanRewriter
from estnltk.taggers.standard_taggers.attribute_comparison_tagger import AttributeComparisonTagger

from estnltk.taggers.combined_tagger import CombinedTagger

from estnltk.taggers.dict_taggers.vocabulary import Vocabulary
from estnltk.taggers.dict_taggers.phrase_tagger import PhraseTagger
from estnltk.taggers.dict_taggers.regex_tagger import RegexTagger
from estnltk.taggers.dict_taggers.span_tagger import SpanTagger

from estnltk.taggers.estner.ner_tagger import NerTagger
from estnltk.taggers.estner.word_level_ner_tagger import WordLevelNerTagger
from estnltk.taggers.estner.fex import NerGazetteerFeatureTagger
from estnltk.taggers.estner.fex import NerGlobalContextFeatureTagger
from estnltk.taggers.estner.fex import NerLocalFeatureTagger
from estnltk.taggers.estner.fex import NerMorphFeatureTagger
from estnltk.taggers.estner.fex import NerSentenceFeatureTagger

from estnltk.taggers.grammar_taggers.grammar_parsing_tagger import GrammarParsingTagger

from estnltk.taggers.raw_text_tagging.date_tagger.date_tagger import DateTagger

from estnltk.taggers.morph_analysis.postanalysis_tagger import PostMorphAnalysisTagger
from estnltk.taggers.morph_analysis.morf import VabamorfTagger
from estnltk.taggers.morph_analysis.gt_morf import GTMorphConverter
from estnltk.taggers.morph_analysis.morf import VabamorfAnalyzer
from estnltk.taggers.morph_analysis.morf import VabamorfDisambiguator
from estnltk.taggers.morph_analysis.userdict_tagger import UserDictTagger
from estnltk.taggers.morph_analysis.vm_analysis_reorderer import MorphAnalysisReorderer
from estnltk.taggers.morph_analysis.vm_est_cat_names import VabamorfEstCatConverter

from estnltk.taggers.morph_analysis.vm_spellcheck import SpellCheckRetagger

from estnltk.taggers.morph_analysis.cb_disambiguator import CorpusBasedMorphDisambiguator
from estnltk.taggers.morph_analysis.vm_corpus_tagger import VabamorfCorpusTagger

from estnltk.taggers.sequential_tagger import SequentialTagger

from estnltk.taggers.standard_taggers.disambiguating_tagger import DisambiguatingTagger
from estnltk.taggers.standard_taggers.enveloping_gap_tagger import EnvelopingGapTagger
from estnltk.taggers.standard_taggers.flatten_tagger import FlattenTagger
from estnltk.taggers.standard_taggers.gap_tagger import GapTagger
from estnltk.taggers.standard_taggers.layer_merge_tagger import MergeTagger
from estnltk.taggers.standard_taggers.diff_tagger import DiffTagger
from estnltk.taggers.standard_taggers.text_segments_tagger import TextSegmentsTagger

from estnltk.taggers.standard_taggers.timex_tagger import TimexTagger

from estnltk.taggers.miscellaneous.robust_date_number_tagger import RobustDateNumberTagger
from estnltk.taggers.miscellaneous.address_tagger import AddressPartTagger
from estnltk.taggers.miscellaneous.address_tagger import AddressGrammarTagger
from estnltk.taggers.miscellaneous.adjective_phrase_tagger import AdjectivePhraseTagger
from estnltk.taggers.miscellaneous.flesch_tagger import SentenceFleschScoreRetagger
from estnltk.taggers.verb_chains import VerbChainDetector

from estnltk.taggers.text_segmentation.tokens_tagger import TokensTagger
from estnltk.taggers.text_segmentation.word_tagger import WordTagger
from estnltk.taggers.text_segmentation.sentence_tokenizer import SentenceTokenizer
from estnltk.taggers.text_segmentation.paragraph_tokenizer import ParagraphTokenizer
from estnltk.taggers.text_segmentation.compound_token_tagger import CompoundTokenTagger
from estnltk.taggers.text_segmentation.clause_segmenter import ClauseSegmenter

# Taggers for processing pretokenized texts:
from estnltk.taggers.text_segmentation.whitespace_tokens_tagger import WhiteSpaceTokensTagger
from estnltk.taggers.text_segmentation.pretokenized_text_compound_tokens_tagger import PretokenizedTextCompoundTokensTagger

from estnltk.taggers.syntax_preprocessing.pronoun_type_retagger import PronounTypeRetagger
from estnltk.taggers.syntax_preprocessing.verb_extension_suffix_tagger import VerbExtensionSuffixRetagger
from estnltk.taggers.syntax_preprocessing.subcat_tagger import SubcatRetagger
from estnltk.taggers.syntax_preprocessing.subcat_tagger import SubcatTagger
from estnltk.taggers.syntax_preprocessing.finite_form_tagger import FiniteFormTagger
from estnltk.taggers.syntax_preprocessing.morph_extended_tagger import MorphExtendedTagger

from estnltk.taggers.syntax.visl_tagger import VislTagger
from estnltk.taggers.syntax.conll_morph_tagger import ConllMorphTagger
from estnltk.taggers.syntax.syntax_dependency_retagger import SyntaxDependencyRetagger
from estnltk.taggers.syntax.maltparser_tagger import MaltParserTagger
from estnltk.taggers.syntax.syntax_diff_retagger import SyntaxDiffRetagger
from estnltk.taggers.syntax.syntax_las_tagger import SyntaxLasTagger
from estnltk.taggers.syntax.udpipe_tagger.udpipe_tagger import UDPipeTagger

from estnltk.taggers.standard_taggers.attribute_comparison_tagger import AttributeComparisonTagger
